library out_nextscene;

(* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version 
 * 1.1 (the "License"); you may not use this file except in compliance with 
 * the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the NextScene Output Module for Lightning.
 *
 * The Initial Developer of the Original Code is
 * Tomsoft.
 * Portions created by Tomsoft are Copyright (C) 2011
 * Tomsoft. All Rights Reserved.
 *
 * Contributor(s):
 *   Tommy Sools <tom@sools.com>
 *
 * ***** END LICENSE BLOCK ***** *)

{$IMAGEBASE $41250000}

uses
  Windows,
  SysUtils,
  Graphics,
  StdCtrls,
  common in '..\common.pas';

{$R *.RES}

type
  TDetails = class(TObject)
    pulsed: Boolean;
  end;

function init(name: PChar; nameLength: DWORD): DWORD; cdecl;
begin
  Result := return('ONextScene|Scene Control', name, nameLength);
end;

procedure finish(); cdecl;
begin
  //
end;

function create(controlHandle: THandle): PLightningModule; cdecl;
var
  myDetails: TDetails;
begin
  New(Result);
  with Result^ do
  begin
    handle        := controlHandle;
    title         := 'NextScene';
    settings      := False;
    width         := -1;
    height        := -1;
    inputTop      := -1;
    infoTop       := -1;
    outputTop     := -1;
    inputs        := 1;
    outputs       := 0;
    inputTooltip  := 'Load next scene pulse';
    outputTooltip := '';
    myDetails     := TDetails.Create;
    details       := myDetails;
  end;
  with myDetails do
    pulsed := False;
  New(PLightningModule2(Result^.reserved));
  PLightningModule2(Result^.reserved)^.reserved := nil;
end;

function  action(lightningModule: PLightningModule; input, output: Integer; inputConnected, outputConnected: PChar; var bridge: TSpectrum): Boolean; cdecl;
var
  details: TDetails; 
begin
  details := TDetails(lightningModule^.details);
  if spectrumAverage(bridge, fftMin, fftMax) > enabledBoundary then
  begin
    if not(details.pulsed) then
    begin
      details.pulsed := True;
      PLightningModule2(lightningModule^.reserved)^.nextScene();
    end;
  end
  else
    details.pulsed := False;
  Result := False;
end;

procedure show(lightningModule: PLightningModule; handle: THandle); cdecl;
begin
  //
end;

procedure hide(lightningModule: PLightningModule); cdecl;
begin
  //
end;

procedure open(lightningModule: PLightningModule; settings: PChar); cdecl;
begin
  //
end;

function  save(lightningModule: PLightningModule; settings: PChar; settingsLength: DWORD): DWORD; cdecl;
begin
  Result := return('', settings, settingsLength);
end;

procedure destroy(lightningModule: PLightningModule); cdecl;
begin
  TDetails(lightningModule^.details).Free;
  Dispose(PLightningModule2(lightningModule^.reserved));
  Dispose(lightningModule);
end;

exports
  init, finish, create, action, show, hide, open, save, destroy;

end.
